<?php

$LANG = array(

#header.php
'MENU'					=> 'Menu',
'HOME'					=> 'Início',
'GOTO_CONTENT'			=> 'Ir ao conte&uacute;do',
'GOTO_MENU'				=> 'Ir ao menu',
'COMMENTS_RSS_FEEDS'	=> 'Fluxo RSS dos coment&aacute;rios',
'COMMENTS'				=> 'Coment&aacute;rios',
'ARTICLES_RSS_FEEDS'	=> 'Fluxo Rss dos artigos',
'ARTICLES'				=> 'Artigos',

# sidebar.php
'CATEGORIES' 			=> 'Categorias',
'LATEST_ARTICLES'		=> 'Ultimos artigos',
'LATEST_COMMENTS'		=> 'Ultimos coment&aacute;rios',
'ARCHIVES'				=> 'Arquivos',

# footer.php
'POWERED_BY'			=> 'Propulsado por',
'PLUXML_DESCRIPTION'	=> 'Blog ou Cms sem banco de dados',
'IN'					=> 'em',
'ADMINISTRATION'		=> 'Administra&ccedil;&atilde;o',
'GOTO_TOP'				=> 'Subir',
'TOP'					=> 'Topo',

# erreur.php
'ERROR'					=> 'Ocorreu um erro, pedimos desculpas pelo inc&oacute;modo',
'BACKTO_HOME'			=> 'Voltar ao &Iacute;ndice',

# common
'WRITTEN_BY'			=> 'Escrito por',
'CLASSIFIED_IN'			=> 'Categorizado em',
'TAGS'					=> 'Tags',

# commentaires.php
'SAID'					=> 'escreveu',
'WRITE_A_COMMENT'		=> 'Escrever um coment&aacute;rio',
'NAME'					=> 'Nome',
'WEBSITE'				=> 'Web-site (facultativo)',
'EMAIL'					=> 'E-mail (facultativo)',
'COMMENT'				=> 'Comment&aacute;rio',
'CLEAR'					=> 'Apagar',
'SEND'					=> 'Enviar',
'COMMENTS_CLOSED'		=> 'Os coment&aacute;rios est&atilde;o fechados',
'ANTISPAM_WARNING'		=> 'Verifica&ccedil;&atilde;o anti-spam',

'REPLY'					=> 'Resposta',
'REPLY_TO'				=> 'Resposta',
'CANCEL'				=> 'Cancelar',

);

?>